@@ -115,7 +115,6 @@ class PostTempView(DetailView):
         current_url = reverse('app_blog-post-detail-temp',
                               kwargs={'slug': self.kwargs['slug']})
         return self.obj
-aaa = PostTempView.as_view()
 
 class PostsWithTag(ListView):
 
@@ -158,10 +157,10 @@ class PostsByDate(ListView):
 
     def get_context_data(self, **kwargs):
         context = super(PostsByDate, self).get_context_data(**kwargs)
-        mytit = "%s %s.%s" % (_('Archive'), str(self.kwargs['month']),
+        mytit = u"%s %s.%s" % (_('Archive'), str(self.kwargs['month']),
                               str(self.kwargs['year']))
 
-        mydesc = "%s: %s.%s" % (_('Bunch of posts on the date'),
+        mydesc = u"%s: %s.%s" % (_('Bunch of posts on the date'),
                                 str(self.kwargs['month']),
                                 str(self.kwargs['year']))
         myarch = str(self.kwargs['month']) + '.' + str(self.kwargs['year'])
